grainscape-defunct: Defunct functions in grainscape

grainscape-defunctR Documentation

Defunct functions in grainscape

Description

These functions are defunct and have been removed from grainscape. They were deprecated in version 0.4.0, when the functions were renamed to drop their gs/gsGOC prefixes (#10), and are removed in version 1.0.0. Use the replacement function named in each function's error message.

Usage

gsMPG(...)

gsGOC(...)

gsGOCCorridor(...)

gsGOCDistance(...)

gsGOCPoint(...)

gsGOCVisualize(...)

gsGraphDataFrame(...)

gsMPGstitch(...)

Arguments

...

Arguments formerly passed to these functions; now ignored.


grainscape documentation built on July 8, 2026, 1:08 a.m.